==> languagewire_translation_provider-12.0.1.tar.gz: languagewire_translation_provider/src/Service/ProjectCreator.php <==
<?php

namespace Drupal\languagewire_translation_provider\Service;

use Drupal\languagewire_translation_provider\Adapter\SystemInterface;
use Drupal\languagewire_translation_provider\Adapter\TMGMT\TmgmtJobInterface;
use Drupal\languagewire_translation_provider\api\Service\Exception\ProjectAlreadyExistsException;
use Drupal\languagewire_translation_provider\Client\ClientInterface;
use Drupal\languagewire_translation_provider\Client\RecoverableException;
use Drupal\languagewire_translation_provider\Content\HtmlPreview\HtmlPreviewTemporaryArtifactsCleaner;
use Drupal\languagewire_translation_provider\Domain\Project;
use Drupal\languagewire_translation_provider\Domain\ProjectStatus;
use Psr\Log\LoggerInterface;

/**
 * Project Creator.
 */
class ProjectCreator {

  /**
   * System.
   *
   * @var \Drupal\languagewire_translation_provider\Adapter\SystemInterface
   */
  private SystemInterface $system;

  /**
   * Logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  private LoggerInterface $logger;

  /**
   * Html preview service.
   *
   * @var \Drupal\languagewire_translation_provider\Service\HtmlPreviewService
   */
  private HtmlPreviewService $htmlPreviewService;

  /**
   * Html preview temporary artifacts cleaner.
   *
   * @var \Drupal\languagewire_translation_provider\Content\HtmlPreview\HtmlPreviewTemporaryArtifactsCleaner
   */
  private HtmlPreviewTemporaryArtifactsCleaner $htmlPreviewTemporaryArtifactsCleaner;

  /**
   * Constructs a new ProjectCreator object.
   *
   * @param \Drupal\languagewire_translation_provider\Adapter\SystemInterface $system
   *   System.
   * @param \Psr\Log\LoggerInterface $logger
   *   Logger.
   */
  public function __construct(
    SystemInterface $system,
    LoggerInterface $logger
  ) {
    $this->system = $system;
    $this->logger = $logger;
  }

  /**
   * Creates a project in the LanguageWire platform.
   */
  public function createProject(Project &$project, ClientInterface $client, bool $isQuoteOrder = FALSE): void {
    $job = $project->getTmgmtJob();

    try {
      $savedDocuments = $project->getDocuments();

      $project = $client->submit($project);
      $project->setDocuments($savedDocuments);
      $project->setStatus(ProjectStatus::uploading());

      $correlationID = $project->getCorrelationId();
      $message = "Translation project '{$correlationID}' was successfully created in the LanguageWire platform.";
      if ($isQuoteOrder) {
        $message = "Translation quote order '{$correlationID}' was successfully created in the LanguageWire platform.";
      }

      $job->addMessage($message);
    }
    catch (RecoverableException $recoverableException) {
      $this->logger->warning("$recoverableException");
      return;
    }
    catch (ProjectAlreadyExistsException $projectAlreadyExistsException) {
      $this->logger->warning("$projectAlreadyExistsException");
      $project->setStatus(ProjectStatus::uploading());
    }
    catch (\Exception $exception) {
      $this->logException($exception, $job);
      $message = "Project creation of '{$project->getCorrelationId()}' has failed. Failure reason: {$exception->getMessage()}.";
      $project->setStatus(ProjectStatus::error());
      $job->cancel($message);
      $job->save();
    }
  }

  /**
   * Logs an exception.
   */
  private function logException(\Exception $exception, TmgmtJobInterface $job): void {
    $this->logger->error("Error occurred when trying to create a translation project for job {$job->title()} "
          . "(ID {$job->jobId()}) in the LanguageWire platform. \n"
          . "Error: $exception");
  }

}

==> languagewire_translation_provider-12.1.0.tar.gz: languagewire_translation_provider/src/Service/ProjectCreator.php <==
<?php

namespace Drupal\languagewire_translation_provider\Service;

use Drupal\languagewire_translation_provider\Adapter\SystemInterface;
use Drupal\languagewire_translation_provider\Adapter\TMGMT\TmgmtJobInterface;
use Drupal\languagewire_translation_provider\api\Service\Exception\ProjectAlreadyExistsException;
use Drupal\languagewire_translation_provider\Client\ClientInterface;
use Drupal\languagewire_translation_provider\Client\RecoverableException;
use Drupal\languagewire_translation_provider\Content\HtmlPreview\HtmlPreviewTemporaryArtifactsCleaner;
use Drupal\languagewire_translation_provider\Domain\Project;
use Drupal\languagewire_translation_provider\Domain\ProjectStatus;
use Psr\Log\LoggerInterface;

/**
 * Project Creator.
 */
class ProjectCreator {

  /**
   * System.
   *
   * @var \Drupal\languagewire_translation_provider\Adapter\SystemInterface
   */
  private SystemInterface $system;

  /**
   * Logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  private LoggerInterface $logger;

  /**
   * Html preview service.
   *
   * @var \Drupal\languagewire_translation_provider\Service\HtmlPreviewService
   */
  private HtmlPreviewService $htmlPreviewService;

  /**
   * Html preview temporary artifacts cleaner.
   *
   * @var \Drupal\languagewire_translation_provider\Content\HtmlPreview\HtmlPreviewTemporaryArtifactsCleaner
   */
  private HtmlPreviewTemporaryArtifactsCleaner $htmlPreviewTemporaryArtifactsCleaner;

  /**
   * Constructs a new ProjectCreator object.
   *
   * @param \Drupal\languagewire_translation_provider\Adapter\SystemInterface $system
   *   System.
   * @param \Psr\Log\LoggerInterface $logger
   *   Logger.
   */
  public function __construct(
    SystemInterface $system,
    LoggerInterface $logger
  ) {
    $this->system = $system;
    $this->logger = $logger;
  }

  /**
   * Creates a project in the LanguageWire platform.
   */
  public function createProject(Project &$project, ClientInterface $client, bool $isQuoteOrder = FALSE, bool $shouldCreate = FALSE): void {
    $job = $project->getTmgmtJob();

    try {
      $savedDocuments = $project->getDocuments();

      if ($shouldCreate) {
        $project = $client->submit($project);
      }

      $project->setDocuments($savedDocuments);
      $project->setStatus(ProjectStatus::uploading());

      $correlationID = $project->getCorrelationId();
      $message = "Translation project '{$correlationID}' was successfully created in the LanguageWire platform.";
      if ($isQuoteOrder) {
        $message = "Translation quote order '{$correlationID}' was successfully created in the LanguageWire platform.";
      }

      $job->addMessage($message);
    }
    catch (RecoverableException $recoverableException) {
      $this->logger->warning("$recoverableException");
      return;
    }
    catch (ProjectAlreadyExistsException $projectAlreadyExistsException) {
      $this->logger->warning("$projectAlreadyExistsException");
      $project->setStatus(ProjectStatus::uploading());
    }
    catch (\Exception $exception) {
      $this->logException($exception, $job);
      $message = "Project creation of '{$project->getCorrelationId()}' has failed. Failure reason: {$exception->getMessage()}.";
      $project->setStatus(ProjectStatus::error());
      $job->cancel($message);
      $job->save();
    }
  }

  /**
   * Logs an exception.
   */
  private function logException(\Exception $exception, TmgmtJobInterface $job): void {
    $this->logger->error("Error occurred when trying to create a translation project for job {$job->title()} "
          . "(ID {$job->jobId()}) in the LanguageWire platform. \n"
          . "Error: $exception");
  }

}
